package gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.impl;

import gov.va.med.pharmacy.peps.common.exception.DataNotFoundException;
import gov.va.med.pharmacy.peps.common.vo.DrugDataVendorVersionVo;
import gov.va.med.pharmacy.peps.external.common.drugdatavendor.capability.VersionCapability;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.EnvironmentInformationCapability;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.EnvironmentInformation;

/**
 * Implementation of VersionCapability that uses FDB Cloud Connector as its data
 * source. Requires the injection of an EnvironmentInformationCapability
 * implementation.
 */
public class VersionCapabilityImpl implements VersionCapability {
    private static final org.apache.log4j.Logger LOG = org.apache.log4j.Logger.getLogger(VersionCapabilityImpl.class);
    private static final String NOT_AVAILABLE = "NOT AVAILABLE";

    private EnvironmentInformationCapability environmentInformationCapability;

    @Override
    public DrugDataVendorVersionVo retrieveDrugDataVendorVersion() {
        EnvironmentInformation environmentInformation = null;
        DrugDataVendorVersionVo vo = null;
        try {
            environmentInformation = getEnvironmentInformationCapability().retrieveEnvironmentInformation();
            vo = transformFDBToVo(environmentInformation);
        } catch (DataNotFoundException e) {
            LOG.warn("No Environment Information Returned.");
        }

        return vo;
    }

    /**
     * Transforms the FDB Cloud Connector EnvironmentInformation object to the
     * MOCHA Server DrugDataVendorVersionVo.
     * 
     * @param environmentInformation
     *            EnvironmentInformation containing FDB Cloud data.
     * @return DrugDataVendorVersionVo
     */
    private DrugDataVendorVersionVo transformFDBToVo(EnvironmentInformation environmentInformation) {
        DrugDataVendorVersionVo vo = new DrugDataVendorVersionVo();
        // The environment information only returns an issue date
        vo.setIssueDate(environmentInformation.getProductionDate().toString());
        vo.setBuildVersion(NOT_AVAILABLE);
        vo.setCustomBuildVersion(NOT_AVAILABLE);
        vo.setCustomDataVersion(NOT_AVAILABLE);
        vo.setCustomIssueDate(NOT_AVAILABLE);
        vo.setDataVersion(NOT_AVAILABLE);
        return vo;
    }

    /**
     * Get the EnvironmentInformationCapability.
     * 
     * @return EnvironmentInformationCapability
     */
    public EnvironmentInformationCapability getEnvironmentInformationCapability() {
        return environmentInformationCapability;
    }

    /**
     * Set the EnvironmentInformationCapability.
     * 
     * @param environmentInformationCapability
     *            The new EnvironmentInformationCapability value
     */
    public void setEnvironmentInformationCapability(EnvironmentInformationCapability environmentInformationCapability) {
        this.environmentInformationCapability = environmentInformationCapability;
    }
}
