package gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.impl.rest;

import gov.va.med.pharmacy.peps.common.exception.DataNotFoundException;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.EnvironmentInformationCapability;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.utility.FDBCloudUtility;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.CallContext;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.EnvironmentInformation;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.EnvironmentInformationResponse;

import java.util.HashMap;
import java.util.Map;

import org.springframework.web.util.UriComponentsBuilder;

/**
 * Implementation of EnvironmentInformationCapability that invokes the FDB Cloud
 * Connector REST API.
 *
 */
public class EnvironmentInformationRestImpl extends FDBCloudRestBase<String, EnvironmentInformationResponse> implements
        EnvironmentInformationCapability {

    private static final String PATH = "EnvironmentInformation?" + URI_COMMON_QUERY_PARMS;

    @Override
    protected Class<EnvironmentInformationResponse> getResponseType() {
        return EnvironmentInformationResponse.class;
    }

    @Override
    public EnvironmentInformation retrieveEnvironmentInformation() throws DataNotFoundException {
        CallContext callContext = FDBCloudUtility.createCallContext();
        Map<String, String> urlVariables = new HashMap<String, String>();
        if (callContext.getCallID() != null) {
            urlVariables.put("callID", callContext.getCallID());
        }
        if (callContext.getCallSystemName() != null) {
            urlVariables.put("callSystemName", callContext.getCallSystemName());
        }
        EnvironmentInformationResponse response = this.call(null, urlVariables);
        return response.getEnvironmentInformation();
    }

    @Override
    protected String getUriTemplate() {
        // String uriTemplate = getBaseURL() + PATH;
        String uriTemplate = UriComponentsBuilder.fromHttpUrl(getBaseURL() + PATH).build().toUriString();
        return uriTemplate;
    }

}
