package gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.impl.rest;

import gov.va.med.pharmacy.peps.common.exception.DataNotFoundException;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.GetProfessionalMonographCapability;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.utility.FDBCloudUtility;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.CallContext;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.DrugDrugMonograph;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.GetProfessionalMonographResponse;

import java.util.HashMap;
import java.util.Map;

import org.springframework.web.util.UriComponentsBuilder;

/**
 * Implementation of GetProfessionalMonographCapability that invokes the FDB
 * Cloud Connector REST API.
 *
 */
public class GetProfessionalMonographRestImpl extends FDBCloudRestBase<String, GetProfessionalMonographResponse>
        implements GetProfessionalMonographCapability {
    private static final org.apache.log4j.Logger LOG = org.apache.log4j.Logger
            .getLogger(GetProfessionalMonographRestImpl.class);

    private static final String PATH = "DrugDrugProfessionalMonographs/{monographID}?" + URI_COMMON_QUERY_PARMS;

    @Override
    protected Class<GetProfessionalMonographResponse> getResponseType() {
        return GetProfessionalMonographResponse.class;
    }

    @Override
    public DrugDrugMonograph getProfessionalMonograph(Integer monographID) {
        if (monographID == null) {
            throw new IllegalArgumentException("MonographID is required.");
        }

        CallContext callContext = FDBCloudUtility.createCallContext();
        Map<String, String> urlVariables = new HashMap<String, String>();
        if (callContext.getCallID() != null) {
            urlVariables.put("callID", callContext.getCallID());
        }
        if (callContext.getCallSystemName() != null) {
            urlVariables.put("callSystemName", callContext.getCallSystemName());
        }

        urlVariables.put("monographID", String.valueOf(monographID));

        try {
            GetProfessionalMonographResponse response = this.call(null, urlVariables);
            return response.getMonograph();
        } catch (DataNotFoundException e) {
            LOG.warn("Professional Monograph not found with id:" + monographID);
        }

        return null;
    }

    @Override
    protected String getUriTemplate() {
        String uriTemplate = UriComponentsBuilder.fromHttpUrl(getBaseURL() + PATH).build().toUriString();
        return uriTemplate;
    }

}
