package gov.va.med.pharmacy.peps.external.common.fdbcloud.model;

/**
 * Base class for ScreenRequests.
 */
public class ScreenRequestBase {

    /** The response fields. */
    private String responseFields;
    /**
     * Determines the maximum number of results that are returned. This
     * parameter is used along with the Offset parameter to paginate data. For
     * example, there are 50 results. If you wanted to return only 25 results
     * per page (1-25 on the first page, 25-60 on the second page), the Limit
     * parameter would be 25.
     */
    private int limit;
    /**
     * Determines the index page number of the data that is returned. This
     * parameter is used along with the Limit parameter to paginate data. The
     * index is 1 based. For example, there are 50 results and the results are
     * displayed with 25 results per page (Limit parameter would be 25). If you
     * only wanted to display results from the second page (that is, results
     * 26-50), the Offset parameter value would be 2.
     */
    private int offset;
    /** The prospective only. */
    private boolean prospectiveOnly;

    /**
     * Instantiates a new screen request base.
     */
    public ScreenRequestBase() {
        super();
    }

    /**
     * Gets the limit.
     *
     * @return the limit
     */
    public int getLimit() {
        return limit;
    }

    /**
     * Sets the limit.
     *
     * @param limit the new limit
     */
    public void setLimit(int limit) {
        this.limit = limit;
    }

    /**
     * Gets the offset.
     *
     * @return the offset
     */
    public int getOffset() {
        return offset;
    }

    /**
     * Sets the offset.
     *
     * @param offset the new offset
     */
    public void setOffset(int offset) {
        this.offset = offset;
    }

    /**
     * Gets the response fields.
     *
     * @return the response fields
     */
    public String getResponseFields() {
        return responseFields;
    }

    /**
     * Sets the response fields.
     *
     * @param responseFields the new response fields
     */
    public void setResponseFields(String responseFields) {
        this.responseFields = responseFields;
    }

    /**
     * Checks if is prospective only.
     *
     * @return true, if is prospective only
     */
    public boolean isProspectiveOnly() {
        return prospectiveOnly;
    }

    /**
     * Sets the prospective only.
     *
     * @param prospectiveOnly the new prospective only
     */
    public void setProspectiveOnly(boolean prospectiveOnly) {
        this.prospectiveOnly = prospectiveOnly;
    }

}
