/**
 * 
 */
package gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.impl.rest;

import gov.va.med.pharmacy.peps.common.exception.DataNotFoundException;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.capability.utility.FDBCloudUtility;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.DDIScreenRequest;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.Screen;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.ScreenDrug;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.ScreenProfile;
import gov.va.med.pharmacy.peps.external.common.fdbcloud.model.ScreenResult;

import java.util.ArrayList;
import java.util.List;

import junit.framework.Assert;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;
import org.junit.Test;

/**
 * JUnit Test of the ScreenRestImpl class.
 *
 */
public class ScreenRestImplTest {

    @Test
    public void testValidResponseWithNotes() throws DataNotFoundException {
        ScreenRestImpl impl = new ScreenRestImpl();

        List<ScreenDrug> screenDrugs = new ArrayList<ScreenDrug>();

        String[] gcnSeqNoList = { "43067", "4", "99999" };
        boolean isProspective = true;
        int uniqueId = 0;
        for (String gcnSeqNo : gcnSeqNoList) {
            ScreenDrug screenDrug = createScreenDrug(gcnSeqNo, isProspective);
            screenDrug.setTag(String.valueOf(uniqueId));
            uniqueId++;
            screenDrugs.add(screenDrug);
        }

        ScreenProfile screenProfile = new ScreenProfile();
        screenProfile.setScreenDrugs(screenDrugs);

        Screen screenRequest = new Screen();
        screenRequest.setCallContext(FDBCloudUtility.createCallContext());
        screenRequest.setScreenProfile(screenProfile);

        DDIScreenRequest ddiScreenRequest = new DDIScreenRequest();
        ddiScreenRequest.setSeverityFilter(9); // Basically includes all
        ddiScreenRequest.setProspectiveOnly(isProspective);
        screenRequest.setDdiScreenRequest(ddiScreenRequest);

        ScreenResult screenResult = impl.call(screenRequest, null);
        Assert.assertNotNull(screenResult);
        ToStringBuilder.setDefaultStyle(ToStringStyle.MULTI_LINE_STYLE);
        System.out.println(screenResult);
    }

    /**
     * Test sending no drugs in a drugcheck. Expected result is a successful
     * response with a ddiscreenresponse that has no drugs in it.
     * 
     * @throws DataNotFoundException
     */
    @Test
    public void testNoDrugs() throws DataNotFoundException {
        ScreenRestImpl impl = new ScreenRestImpl();

        List<ScreenDrug> screenDrugs = new ArrayList<ScreenDrug>();

        String[] gcnSeqNoList = {};
        boolean isProspective = true;
        int uniqueId = 0;
        for (String gcnSeqNo : gcnSeqNoList) {
            ScreenDrug screenDrug = createScreenDrug(gcnSeqNo, isProspective);
            screenDrug.setTag(String.valueOf(uniqueId));
            uniqueId++;
            screenDrugs.add(screenDrug);
        }

        ScreenProfile screenProfile = new ScreenProfile();
        screenProfile.setScreenDrugs(screenDrugs);

        Screen screenRequest = new Screen();
        screenRequest.setCallContext(FDBCloudUtility.createCallContext());
        screenRequest.setScreenProfile(screenProfile);

        DDIScreenRequest ddiScreenRequest = new DDIScreenRequest();
        ddiScreenRequest.setSeverityFilter(9); // Basically includes all
        ddiScreenRequest.setProspectiveOnly(isProspective);
        screenRequest.setDdiScreenRequest(ddiScreenRequest);

        ScreenResult screenResult = impl.call(screenRequest, null);
        Assert.assertNotNull(screenResult);
        Assert.assertTrue(screenResult.getIsSuccessful());
        Assert.assertNotNull(screenResult.getDDIScreenResponse());
        Assert.assertTrue(screenResult.getDDIScreenResponse().getIsSuccessful());
        Assert.assertEquals("Expected zero entries in ddiScreenResponse", 0, screenResult.getDDIScreenResponse()
                .getTotalCount());
        ToStringBuilder.setDefaultStyle(ToStringStyle.MULTI_LINE_STYLE);
        System.out.println(screenResult);
    }

    private ScreenDrug createScreenDrug(String gcnSeqNo, boolean isProspective) {
        ScreenDrug screenDrug = new ScreenDrug();
        screenDrug.setDrugConceptType(2); // DispensibleGeneric
        screenDrug.setDrugID(gcnSeqNo);
        screenDrug.setProspective(isProspective);
        return screenDrug;
    }

}
