package gov.va.med.pharmacy.peps.external.common.preencapsulation.test.multiplerequests;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Properties;
import java.util.Set;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class MultipleRequests {
    private static final Log LOGGER = LogFactory.getLog(MultipleRequests.class);

    private static final SimpleDateFormat dateFormatter = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss:SSS");
    private static final String PROPERTY_FILE_NAME = "properties/MultipleRequests.properties";
    private Properties executionProperties = new Properties();
    
    public MultipleRequests() {
        try {
            loadProperties();
            process();
        } catch(Exception e) {
            LOGGER.error(e.getMessage(), e);
        }
    }
    
    private void loadProperties() throws Exception {
        executionProperties.load(Thread.currentThread().getContextClassLoader().getResourceAsStream(PROPERTY_FILE_NAME));
    }

    private void process() {
        List<Thread> threads = buildThreads();
        startThreads(threads);
        monitorThreads(threads);
    }

    private List<Thread> buildThreads() {
        try {
            printMessage("Beginning thread creation" );
            List<Thread> threads = new ArrayList<Thread>();
            Set<Object> keySet = executionProperties.keySet();
            for ( Object key : keySet ) {
                printMessage("Creating thread name " + key.toString());
                String request = executionProperties.getProperty(key.toString());
                
                threads.add(new Thread(new RunnableThreadTest(key.toString(), request)));
            }
            return threads;
        } finally {
            printMessage("Exiting thread creation");
        }
    }
    
    /**
     * @param threads
     */
    private void startThreads(List<Thread> threads) {
        try {
            printMessage("Starting threads");
            if ( threads.size() > 0 ) {
                for ( int i = 0; i < threads.size(); i++ ) {
                    threads.get(i).start();
                }
            }
        } finally {
            printMessage("Threads started");
        }
    }
    
    private void monitorThreads(List<Thread> threads) {
        boolean quit = false;
        boolean stillAlive;
        while ( ! quit ) {
            stillAlive = false;
            for ( int i = 0; i < threads.size(); i++ ) {
                printMessage("Checking thread number " + i + ".  isAlive = " + threads.get(i).isAlive());
                if ( threads.get(i).isAlive()) {
                    stillAlive = true;
                }
                if ( ! stillAlive ) {
                    quit = true;
                }
            }
            try {
                if ( ! quit )
                Thread.sleep(2000);
            } catch(InterruptedException ie) {
                // okay to be interrupted
            }
        }
    }
    
    private void printMessage(String msg) {
        LOGGER.info(msg + ": " + dateFormatter.format(new Date(System.currentTimeMillis())));
    }
    
    public static void main(String[] args) {
        MultipleRequests mr = new MultipleRequests();
    }
}
